==> openshift-model-5.8.0-sources.jar: io/fabric8/openshift/api/model/UserFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface UserFluent<A extends io.fabric8.openshift.api.model.UserFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public java.lang.String getFullName();
  public A withFullName(java.lang.String fullName);
  public java.lang.Boolean hasFullName();
  
  /**
   * Method is deprecated. use withFullName instead.
   */
  @java.lang.Deprecated
  public A withNewFullName(java.lang.String arg0);
  public A addToGroups(java.lang.Integer index,java.lang.String item);
  public A setToGroups(java.lang.Integer index,java.lang.String item);
  public A addToGroups(java.lang.String... items);
  public A addAllToGroups(java.util.Collection<java.lang.String> items);
  public A removeFromGroups(java.lang.String... items);
  public A removeAllFromGroups(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getGroups();
  public java.lang.String getGroup(java.lang.Integer index);
  public java.lang.String getFirstGroup();
  public java.lang.String getLastGroup();
  public java.lang.String getMatchingGroup(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingGroup(java.util.function.Predicate<java.lang.String> predicate);
  public A withGroups(java.util.List<java.lang.String> groups);
  public A withGroups(java.lang.String... groups);
  public java.lang.Boolean hasGroups();
  public A addNewGroup(java.lang.String arg0);
  public A addToIdentities(java.lang.Integer index,java.lang.String item);
  public A setToIdentities(java.lang.Integer index,java.lang.String item);
  public A addToIdentities(java.lang.String... items);
  public A addAllToIdentities(java.util.Collection<java.lang.String> items);
  public A removeFromIdentities(java.lang.String... items);
  public A removeAllFromIdentities(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getIdentities();
  public java.lang.String getIdentity(java.lang.Integer index);
  public java.lang.String getFirstIdentity();
  public java.lang.String getLastIdentity();
  public java.lang.String getMatchingIdentity(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingIdentity(java.util.function.Predicate<java.lang.String> predicate);
  public A withIdentities(java.util.List<java.lang.String> identities);
  public A withIdentities(java.lang.String... identities);
  public java.lang.Boolean hasIdentities();
  public A addNewIdentity(java.lang.String arg0);
  public java.lang.String getKind();
  public A withKind(java.lang.String kind);
  public java.lang.Boolean hasKind();
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata();
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata();
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata);
  public java.lang.Boolean hasMetadata();
  public io.fabric8.openshift.api.model.UserFluent.MetadataNested<A> withNewMetadata();
  public io.fabric8.openshift.api.model.UserFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public io.fabric8.openshift.api.model.UserFluent.MetadataNested<A> editMetadata();
  public io.fabric8.openshift.api.model.UserFluent.MetadataNested<A> editOrNewMetadata();
  public io.fabric8.openshift.api.model.UserFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ObjectMetaFluent<io.fabric8.openshift.api.model.UserFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/UserFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface UserFluent<A extends io.fabric8.openshift.api.model.UserFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public java.lang.String getFullName();
  public A withFullName(java.lang.String fullName);
  public java.lang.Boolean hasFullName();
  
  /**
   * Method is deprecated. use withFullName instead.
   */
  @java.lang.Deprecated
  public A withNewFullName(java.lang.String arg0);
  public A addToGroups(java.lang.Integer index,java.lang.String item);
  public A setToGroups(java.lang.Integer index,java.lang.String item);
  public A addToGroups(java.lang.String... items);
  public A addAllToGroups(java.util.Collection<java.lang.String> items);
  public A removeFromGroups(java.lang.String... items);
  public A removeAllFromGroups(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getGroups();
  public java.lang.String getGroup(java.lang.Integer index);
  public java.lang.String getFirstGroup();
  public java.lang.String getLastGroup();
  public java.lang.String getMatchingGroup(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingGroup(java.util.function.Predicate<java.lang.String> predicate);
  public A withGroups(java.util.List<java.lang.String> groups);
  public A withGroups(java.lang.String... groups);
  public java.lang.Boolean hasGroups();
  public A addNewGroup(java.lang.String arg0);
  public A addToIdentities(java.lang.Integer index,java.lang.String item);
  public A setToIdentities(java.lang.Integer index,java.lang.String item);
  public A addToIdentities(java.lang.String... items);
  public A addAllToIdentities(java.util.Collection<java.lang.String> items);
  public A removeFromIdentities(java.lang.String... items);
  public A removeAllFromIdentities(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getIdentities();
  public java.lang.String getIdentity(java.lang.Integer index);
  public java.lang.String getFirstIdentity();
  public java.lang.String getLastIdentity();
  public java.lang.String getMatchingIdentity(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingIdentity(java.util.function.Predicate<java.lang.String> predicate);
  public A withIdentities(java.util.List<java.lang.String> identities);
  public A withIdentities(java.lang.String... identities);
  public java.lang.Boolean hasIdentities();
  public A addNewIdentity(java.lang.String arg0);
  public java.lang.String getKind();
  public A withKind(java.lang.String kind);
  public java.lang.Boolean hasKind();
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata();
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata();
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata);
  public java.lang.Boolean hasMetadata();
  public io.fabric8.openshift.api.model.UserFluent.MetadataNested<A> withNewMetadata();
  public io.fabric8.openshift.api.model.UserFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public io.fabric8.openshift.api.model.UserFluent.MetadataNested<A> editMetadata();
  public io.fabric8.openshift.api.model.UserFluent.MetadataNested<A> editOrNewMetadata();
  public io.fabric8.openshift.api.model.UserFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ObjectMetaFluent<io.fabric8.openshift.api.model.UserFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  
}
